@@ -26,10 +26,10 @@
 
 This AWS Solutions Construct implements an AWS IoT MQTT topic rule and an AWS Lambda function pattern.
 
-Here is a minimal deployable pattern definition:
+Here is a minimal deployable pattern definition in Typescript:
 
 ```javascript
-const { IotToLambdaProps, IotToLambda } = require('@aws-solutions-constructs/aws-iot-lambda');
+const { IotToLambdaProps, IotToLambda } from '@aws-solutions-constructs/aws-iot-lambda';
 
 const props: IotToLambdaProps = {
     lambdaFunctionProps: {
@@ -47,7 +47,7 @@ const props: IotToLambdaProps = {
     }
 };
 
-new IotToLambda(stack, 'test-iot-lambda-integration', props);
+new IotToLambda(this, 'test-iot-lambda-integration', props);
 ```
 
 ## Initializer
@@ -87,7 +87,7 @@ Out of the box implementation of the Construct without any override will set the
 
 ### AWS Lambda Function
 
-* Configure least privilege access IAM role for Lambda function
+* Configure limited privilege access IAM role for Lambda function
 * Enable reusing connections with Keep-Alive for NodeJs Lambda function
 * Enable X-Ray Tracing
 
